@@ -54,7 +54,7 @@ class Edk2CiBuildSetup(Edk2MultiPkgAwareInvocable):
         self.git_update = args.git_update
         self.omnicache_path = args.omnicache_path
         if (self.omnicache_path is not None) and (not os.path.exists(self.omnicache_path)):
-            logging.warning(f"Omnicache path set to invalid path: {args.omnicache_Path}")
+            logging.warning(f"Omnicache path set to invalid path: {args.omnicache_path}")
             self.omnicache_path = None
 
         super().RetrieveCommandLineOptions(args)
