@@ -163,43 +163,6 @@ class TestNugetDependency(unittest.TestCase):
             ext_dep.fetch()
         self.assertFalse(ext_dep.verify())
 
-    def test_normalize_version(self):
-        version1 = "5.10.05.0"
-        proper_version1 = "5.10.5"
-        self.assertEqual(proper_version1, NugetDependency.normalize_version(version1))
-        version2 = "6.10"
-        proper_version2 = "6.10.0"
-        self.assertEqual(proper_version2, NugetDependency.normalize_version(version2))
-        version3 = "6"
-        proper_version3 = "6.0.0"
-        self.assertEqual(proper_version3, NugetDependency.normalize_version(version3))
-        version4 = "6-beta"
-        proper_version4 = "6.0.0-beta"
-        self.assertEqual(proper_version4, NugetDependency.normalize_version(version4))
-        version5 = "3.2.1.-alpha"
-        proper_version5 = "3.2.1-alpha"
-        self.assertEqual(proper_version5, NugetDependency.normalize_version(version5))
-        version6 = "3.2.1.0-rc1"
-        proper_version6 = "3.2.1-rc1"
-        self.assertEqual(proper_version6, NugetDependency.normalize_version(version6))
-        # try some bad cases
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("not a number")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("6.0-beta-beta")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("6.0-bad")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("6.0-")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("--")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("6-")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version("")
-        with self.assertRaises(ValueError):
-            NugetDependency.normalize_version(bad_version)
-
     # missing case
     def test_download_missing_nuget(self):
         ext_dep_file_path = os.path.join(test_dir, "hw_ext_dep.json")
